@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -42,10 +29,10 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Table Format"));
-        QVBoxLayout *mainLayout = new QVBoxLayout(q);
+        auto *mainLayout = new QVBoxLayout(q);
 
         QWidget *page = new QWidget(q);
-        QVBoxLayout *lay = new QVBoxLayout(page);
+        auto *lay = new QVBoxLayout(page);
         lay->setContentsMargins(0, 0, 0, 0);
         tableWidget = new InsertTableWidget;
         lay->addWidget(tableWidget);
@@ -53,7 +40,7 @@ public:
         KSeparator *sep = new KSeparator;
         lay->addWidget(sep);
 
-        QHBoxLayout *hbox = new QHBoxLayout;
+        auto *hbox = new QHBoxLayout;
         QLabel *lab = new QLabel(i18n("Spacing:"));
         hbox->addWidget(lab);
         spacing = new QSpinBox;
