@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtexteditor.h"
@@ -69,6 +56,30 @@ public:
         supportFeatures |= RichTextEditor::TextToSpeech;
         supportFeatures |= RichTextEditor::AllowTab;
         supportFeatures |= RichTextEditor::AllowWebShortcut;
+
+        // Workaround QTextEdit behavior: if the cursor points right after the link
+        // and start typing, the char format is kept. If user wants to write normal
+        // text right after the link, the only way is to move cursor at the next character
+        // (say for "<a>text</a>more text" the character has to be before letter "o"!)
+        // It's impossible if the whole document ends with a link.
+        // The same happens when text starts with a link: it's impossible to write normal text before it.
+        QObject::connect(q, &RichTextEditor::cursorPositionChanged, q, [this](){
+            QTextCursor c = q->textCursor();
+            if (c.charFormat().isAnchor() && !c.hasSelection()) {
+                QTextCharFormat fmt;
+                // If we are at block start or end (and at anchor), we just set the "default" format
+                if (!c.atBlockEnd() && !c.atBlockStart() && !c.hasSelection()) {
+                    QTextCursor probe = c;
+                    // Otherwise, if the next character is not a link, we just grab it's format
+                    probe.movePosition(QTextCursor::NextCharacter);
+                    if (!probe.charFormat().isAnchor()) {
+                        fmt = probe.charFormat();
+                    }
+                }
+                c.setCharFormat(fmt);
+                q->setTextCursor(c);
+            }
+        });
     }
 
     ~RichTextEditorPrivate()
@@ -79,13 +90,13 @@ public:
 
     QStringList ignoreSpellCheckingWords;
     RichTextEditor *const q;
-    KPIMTextEdit::TextMessageIndicator *textIndicator = nullptr;
+    KPIMTextEdit::TextMessageIndicator *const textIndicator;
     QString spellCheckingConfigFileName;
     QString spellCheckingLanguage;
     QTextDocumentFragment originalDoc;
     Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
     Sonnet::Speller *speller = nullptr;
-    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager = nullptr;
+    KIO::KUriFilterSearchProviderActions *const webshortcutMenuManager;
     RichTextEditor::SupportFeatures supportFeatures;
     int mInitialFontSize;
     bool customPalette = false;
@@ -206,7 +217,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
 
                 if (checkSpellingEnabled() && d->activateLanguageMenu) {
                     QMenu *languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
-                    QActionGroup *languagesGroup = new QActionGroup(languagesMenu);
+                    auto *languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
                     QString defaultSpellcheckingLanguage = spellCheckingLanguage();
@@ -423,7 +434,7 @@ void RichTextEditor::checkSpelling(bool force)
         }
         return;
     }
-    Sonnet::BackgroundChecker *backgroundSpellCheck = new Sonnet::BackgroundChecker;
+    auto *backgroundSpellCheck = new Sonnet::BackgroundChecker;
     if (backgroundSpellCheck->speller().availableBackends().isEmpty()) {
         if (force) {
             if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("No backend available for spell checking. Do you want to send the email anyways?"))) {
@@ -443,8 +454,8 @@ void RichTextEditor::checkSpelling(bool force)
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
-    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : nullptr);
-    QDialogButtonBox *buttonBox = spellDialog->findChild<QDialogButtonBox *>();
+    auto *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : nullptr);
+    auto *buttonBox = spellDialog->findChild<QDialogButtonBox *>();
     if (buttonBox) {
         QPushButton *skipButton = new QPushButton(i18n("Skip"));
         buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
@@ -673,7 +684,7 @@ void RichTextEditor::slotToggleAutoSpellCheck()
 
 void RichTextEditor::slotLanguageSelected()
 {
-    QAction *languageAction = static_cast<QAction *>(QObject::sender());
+    auto *languageAction = static_cast<QAction *>(QObject::sender());
     setSpellCheckingLanguage(languageAction->data().toString());
 }
 
@@ -697,7 +708,7 @@ void RichTextEditor::deleteWordForward()
 bool RichTextEditor::event(QEvent *ev)
 {
     if (ev->type() == QEvent::ShortcutOverride) {
-        QKeyEvent *e = static_cast<QKeyEvent *>(ev);
+        auto *e = static_cast<QKeyEvent *>(ev);
         if (overrideShortcut(e)) {
             e->accept();
             return true;
@@ -911,6 +922,12 @@ void RichTextEditor::keyPressEvent(QKeyEvent *event)
     } else if (event->key() == Qt::Key_Down && isControlClicked && isShiftClicked) {
         moveLineUpDown(false);
         event->accept();
+    } else if (event->key() == Qt::Key_Up && isControlClicked) {
+        moveCursorBeginUpDown(true);
+        event->accept();
+    } else if (event->key() == Qt::Key_Down && isControlClicked) {
+        moveCursorBeginUpDown(false);
+        event->accept();
     } else {
         QTextEdit::keyPressEvent(event);
     }
@@ -935,13 +952,25 @@ void RichTextEditor::slotZoomReset()
     }
 }
 
+void RichTextEditor::moveCursorBeginUpDown(bool moveUp)
+{
+    QTextCursor cursor = textCursor();
+    QTextCursor move = cursor;
+    move.beginEditBlock();
+    cursor.clearSelection();
+    move.movePosition(QTextCursor::StartOfBlock);
+    move.movePosition(moveUp ? QTextCursor::PreviousBlock : QTextCursor::NextBlock);
+    move.endEditBlock();
+    setTextCursor(move);
+}
+
 void RichTextEditor::moveLineUpDown(bool moveUp)
 {
     QTextCursor cursor = textCursor();
     QTextCursor move = cursor;
     move.beginEditBlock();
 
-    bool hasSelection = cursor.hasSelection();
+    const bool hasSelection = cursor.hasSelection();
 
     if (hasSelection) {
         move.setPosition(cursor.selectionStart());
@@ -953,7 +982,7 @@ void RichTextEditor::moveLineUpDown(bool moveUp)
         move.movePosition(QTextCursor::StartOfBlock);
         move.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
     }
-    QString text = move.selectedText();
+    const QString text = move.selectedText();
 
     move.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor);
     move.removeSelectedText();
