@@ -1,20 +1,7 @@
 /*
- * Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "texteditorcompleter.h"
@@ -45,7 +32,7 @@ public:
     }
 
     void setCompletion(const QString &completion);
-    QString wordUnderCursor() const;
+    Q_REQUIRED_RESULT QString wordUnderCursor() const;
     void createCompleter();
     void completeText();
     QString excludeOfCharacters;
@@ -86,7 +73,7 @@ QString TextEditorCompleter::TextEditorCompleterPrivate::wordUnderCursor() const
 
     tc.anchor();
     const QString eowStr = excludeOfCharacters.isEmpty() ? eow : excludeOfCharacters;
-    while (1) {
+    while (true) {
         // vHanda: I don't understand why the cursor seems to give a pos 1 past the last char instead
         // of just the last char.
         int pos = tc.position() - 1;
